@@ -33,10 +33,11 @@ import signal
 import string
 # pylint:enable=W0402
 import subprocess
+import sys
 import time
 
 from json import dumps, loads
-from os import environ, makedirs, kill, unlink
+from os import environ, kill, makedirs, unlink
 from os.path import abspath, exists, join
 
 from distutils.spawn import find_executable
@@ -46,24 +47,52 @@ from ubuntuone.devtools.services import (
     get_arbitrary_port,
 )
 
+# pylint: disable=C0103
+if sys.platform == 'win32':
+    AUTH_PROCESS_PATH = r'C:\squid\libexec\ncsa_auth.exe'
+    SQUID_START_ARGS = ['-f']
+else:
+    AUTH_PROCESS_PATH = '/usr/lib/%s/ncsa_auth'
+    SQUID_START_ARGS = ['-N', '-X', '-f']
+# pylint: enable=C0103
+
 SQUID_CONFIG_FILE = 'squid.conf.in'
 SQUID_DIR = 'squid'
-AUTH_PROCESS_PATH = '/usr/lib/%s/ncsa_auth'
 SPOOL_DIR = 'spool'
 AUTH_FILE = 'htpasswd'
 PROXY_ENV_VAR = 'SQUID_PROXY_SETTINGS'
 
 
+def format_config_path(path):
+    """Return the path correctly formatted for the config file."""
+    # squid cannot handle correctly paths with a single \
+    return path.replace('\\', '\\\\')
+
+
+def get_auth_process_path(squid_version):
+    """Return the path to the auth executable."""
+    if sys.platform == 'win32':
+        path = find_executable('ncsa_auth')
+        if path is None:
+            path = AUTH_PROCESS_PATH
+        return format_config_path(path)
+    else:
+        squid = 'squid3' if squid_version == 3 else 'squid'
+        path = AUTH_PROCESS_PATH % squid
+        return path
+
+
 def get_squid_executable():
     """Return the squid executable of the system."""
     # try with squid and if not present try with squid3 for newer systems
     # (Ubuntu P). We also return the path to the auth process so that we can
     # point to the correct one.
     squid = find_executable('squid3')
-    auth_process = AUTH_PROCESS_PATH % 'squid3'
+    version = 3
     if squid is None:
+        version = 2
         squid = find_executable('squid')
-        auth_process = AUTH_PROCESS_PATH % 'squid'
+    auth_process = get_auth_process_path(version)
     return squid, auth_process
 
 
@@ -72,6 +101,21 @@ def get_htpasswd_executable():
     return find_executable('htpasswd')
 
 
+def kill_squid(squid_pid):
+    """Kill the squid process."""
+    if sys.platform == 'win32':
+        # pylint: disable=F0401
+        import win32api
+        import win32con
+        # pylint: enable=F0401
+
+        handle = win32api.OpenProcess(win32con.PROCESS_TERMINATE, 0, squid_pid)
+        win32api.TerminateProcess(handle, 0)
+        win32api.CloseHandle(handle)
+    else:
+        kill(squid_pid, signal.SIGKILL)
+
+
 def _make_random_string(count):
     """Make a random string of the given length."""
     entropy = random.SystemRandom()
@@ -95,7 +139,7 @@ def _get_spool_temp_path(tempdir=''):
     path = abspath(path)
     if not exists(path):
         makedirs(path)
-    return path
+    return format_config_path(path)
 
 
 def _get_squid_temp_path(tempdir=''):
@@ -105,7 +149,7 @@ def _get_squid_temp_path(tempdir=''):
     path = abspath(path)
     if not exists(path):
         makedirs(path)
-    return path
+    return format_config_path(join(path, ''))
 
 
 def _get_auth_temp_path(tempdir=''):
@@ -114,7 +158,7 @@ def _get_auth_temp_path(tempdir=''):
     auth_file = join(basedir, AUTH_FILE)
     if not exists(basedir):
         makedirs(basedir)
-    return auth_file
+    return format_config_path(auth_file)
 
 
 def store_proxy_settings(settings):
@@ -238,19 +282,25 @@ class SquidRunner(object):
         self._generate_auth_file(tempdir)
         self._generate_config_file(tempdir)
         self._generate_swap(self.config_file)
-        squid_args = ['-N', '-X', '-f', self.config_file]
+        squid_args = SQUID_START_ARGS
+        squid_args.append(self.config_file)
         sp = subprocess.Popen([self.squid] + squid_args,
                               stdout=subprocess.PIPE,
                               stderr=subprocess.PIPE)
         store_proxy_settings(self.settings)
         if not self._is_squid_running():
-            raise SquidLaunchError('Could not start squid.')
+            # grab the stdout and stderr to provide more information
+            output = sp.stdout.read()
+            err = sp.stderr.read()
+            msg = 'Could not start squid:\nstdout:\n%s\nstderr\n%s' % (
+                output, err)
+            raise SquidLaunchError(msg)
         self.squid_pid = sp.pid
         self.running = True
 
     def stop_service(self):
         """Stop our proxy,"""
-        kill(self.squid_pid, signal.SIGKILL)
+        kill_squid(self.squid_pid)
         delete_proxy_settings()
         self.running = False
         unlink(self.config_file)
