@@ -113,6 +113,15 @@ def skipIfNotOS(current_os, reason):
     return _id
 
 
+def skipIfJenkins(current_os, reason):
+    """Skip test for a particular os or lists of them
+       when running on Jenkins."""
+    if os.getenv("JENKINS", False) and (sys.platform in current_os or
+                                        sys.platform == current_os):
+        return skipTest(reason)
+    return _id
+
+
 # pylint: enable=C0103
 
 
